// Tataroiu Bogdan-Cristian - verificator problema hacker
#include <cstdio>
#include <cstdlib>
#include <ctime>
#include <cassert>
#include <set>

using namespace std;

const int MAXN = 100000;
const int MAXC = 64;
const int MAXlogN = 17;

static int N, M;
static set<pair<int, int> > con[MAXN];
static int log2[MAXN], p[MAXlogN][MAXN], depth[MAXN], sum[MAXN];

void dfs(int k) {
    set<pair<int, int> > :: iterator it;
    for (it = con[k].begin(); it != con[k].end(); it++) {
        if (it->first == p[0][k]) {
            continue;
        }

        p[0][it->first] = k;
        depth[it->first] = depth[k] + 1;
        sum[it->first] = sum[k] + it->second;
        dfs(it->first);
    }
}

inline int lca(int x, int y) {
    for (; depth[x] > depth[y]; x = p[log2[depth[x] - depth[y]]][x]);
    for (; depth[x] < depth[y]; y = p[log2[depth[y] - depth[x]]][y]);

    if (x == y) {
        return x;
    }

    int step = log2[depth[x]];
    for (; step >= 0; step -= 1) {
        if (p[step][x] != p[step][y]) {
            x = p[step][x];
            y = p[step][y];
        }
    }
    return p[0][x];
}

inline int dist(int x, int y) {
    int lcaxy = lca(x, y);
    return sum[x] + sum[y] - 2 * sum[lcaxy];
}

inline void die(int scor, const char msg[]) {
    printf("%d %s\n", scor, msg);
    exit(0);
}

int main() {
    log2[1] = 0;
    for (int i = 2; i < MAXN; i++) {
        log2[i] = log2[i - 1];
        if (i == (1 << (log2[i] + 1))) {
            log2[i] += 1;
        }
    }

    assert(freopen("hacker.in", "rt", stdin));
    assert(scanf("%d %d", &N, &M) == 2);
    assert(1 <= N && N <= MAXN);
    for (int i = 0; i + 1 < N; i++) {
        int x, y, cst;
        assert(scanf("%d %d %d", &x, &y, &cst) == 3);
        x--; y--;
        con[x].insert(make_pair(y, cst));
        con[y].insert(make_pair(x, cst));
    }

    dfs(0);
    for (int i = 1; i < MAXlogN; i++) {
        for (int j = 0; j < N; j++) {
            p[i][j] = p[i - 1][p[i - 1][j]];
        }
    }

    FILE *out = fopen("hacker.out", "rt");
    if (!out) {
        die(0, "Fisier de iesire lipsa!");
    }
    for (int i = 0; i < M; i++) {
        int nod, in_dist;
        assert(scanf("%d %d", &nod, &in_dist) == 2);
        nod -= 1;

        int ox, oy, op;
        if (fscanf(out, "%d %d %d", &ox, &oy, &op) != 3) {
            die(0, "Fisier de iesire -insuficient- incomplet!");
        }
        if (ox > N || ox < 1 || oy > N || oy < 1) {
            die(0, "Raspuns -mediocru- gresit!");
        }
        ox -= 1; oy -= 1;

        set<pair<int, int> > :: iterator it;
        it = con[ox].lower_bound(make_pair(oy, 0));
        if (it == con[ox].end() || it->first != oy) {
            /* Nu exista muchie intre ox si oy */
            die(0, "Raspuns -mediocru- gresit!");
        }
        if (op < 0 || op > it->second) {
            die(0, "Raspuns -mediocru- gresit!");
        }

        int dx = dist(nod, ox), dy = dist(nod, oy);
        int d;
        if (dx < dy) {
            d = dx + op;
        } else {
            d = dx - op;
        }
        if (d != in_dist) {
            die(0, "Raspuns -mediocru- gresit!");
        }
    }

    die(10, "Bezea.");

    return 0;
}
